@@ -24,8 +24,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 import os
 import os.path
 import time
-import yaml # Howell-Clark version
 import sys
+
 HAS_YUM = True
 try:
     import yum
@@ -195,7 +195,7 @@ class RepoSync:
                     mdoptions.append("-g %s" % groupmdfile)
                 if rmd.repoData.has_key("prestodelta"):
                     # need createrepo >= 0.9.7 to add deltas
-                    if utils.check_dist() == "redhat" or utils.check_dist() == "suse":
+                    if utils.check_dist() in ("redhat","fedora","centos","scientific linux","suse"):
                         cmd = "/usr/bin/rpmquery --queryformat=%{VERSION} createrepo"
                         createrepo_ver = utils.subprocess_get(self.logger, cmd)
                         if createrepo_ver >= "0.9.7":
@@ -536,6 +536,9 @@ class RepoSync:
         config_file = open(fname, "w+")
         config_file.write("[%s]\n" % repo.name)
         config_file.write("name=%s\n" % repo.name)
+        if 'exclude' in repo.yumopts.keys():
+            config_file.write("exclude=%s\n" % repo.yumopts['exclude'])
+            self.logger.debug("excluding: %s" % repo.yumopts['exclude'])
         optenabled = False
         optgpgcheck = False
         if output:
@@ -585,7 +588,12 @@ class RepoSync:
         a safeguard.
         """
         # all_path = os.path.join(repo_path, "*")
-        cmd1 = "chown -R root:apache %s" % repo_path
+        owner = "root:apache"
+        if os.path.exists("/etc/SuSE-release"):
+            owner = "root:www"
+
+        cmd1 = "chown -R "+owner+" %s" % repo_path
+
         utils.subprocess_call(self.logger, cmd1)
 
         cmd2 = "chmod -R 755 %s" % repo_path
