@@ -27,6 +27,7 @@ import glob
 import time
 import random
 import os
+from threading import Lock
 
 import action_litesync
 import item_system
@@ -49,6 +50,7 @@ class Collection:
         self.clear()
         self.api = self.config.api
         self.lite_sync = None
+        self.lock = Lock()
 
     def factory_produce(self,config,seed_data):
         """
@@ -93,9 +95,13 @@ class Collection:
         if len(kargs) == 1 and kargs.has_key("name") and not return_list:
             return self.listing.get(kargs["name"].lower(), None)
 
-        for (name, obj) in self.listing.iteritems():
-            if obj.find_match(kargs, no_errors=no_errors):
-                matches.append(obj)
+        self.lock.acquire()
+        try:
+            for (name, obj) in self.listing.iteritems():
+                if obj.find_match(kargs, no_errors=no_errors):
+                    matches.append(obj)
+        finally:
+            self.lock.release()
 
         if not return_list:
             if len(matches) == 0:
@@ -312,14 +318,22 @@ class Collection:
 
         if not save:
             # don't need to run triggers, so add it already ...
-            self.listing[ref.name.lower()] = ref
+            self.lock.acquire()
+            try:
+                self.listing[ref.name.lower()] = ref
+            finally:
+                self.lock.release()
 
         # perform filesystem operations
         if save:
             # failure of a pre trigger will prevent the object from being added
             if with_triggers:
                 utils.run_triggers(self.api, ref,"/var/lib/cobbler/triggers/add/%s/pre/*" % self.collection_type(), [], logger)
-            self.listing[ref.name.lower()] = ref
+            self.lock.acquire()
+            try:
+                self.listing[ref.name.lower()] = ref
+            finally:
+                self.lock.release()
 
             # save just this item if possible, if not, save
             # the whole collection
