@@ -65,7 +65,11 @@ class Images(collection.Collection):
                     lite_sync = action_litesync.BootLiteSync(self.config, logger=logger)
                     lite_sync.remove_single_image(name)
 
-            del self.listing[name]
+            self.lock.acquire()
+            try:
+                del self.listing[name]
+            finally:
+                self.lock.release()
             self.config.serialize_delete(self, obj)
 
             if with_delete:
