@@ -68,7 +68,11 @@ class Profiles(collection.Collection):
             if with_delete:
                 if with_triggers: 
                     utils.run_triggers(self.config.api, obj, "/var/lib/cobbler/triggers/delete/profile/pre/*", [], logger)
-            del self.listing[name]
+            self.lock.acquire()
+            try:
+                del self.listing[name]
+            finally:
+                self.lock.release()
             self.config.serialize_delete(self, obj)
             if with_delete:
                 if with_triggers: 
