@@ -2,8 +2,8 @@
 Builds out filesystem trees/data based on the object tree.
 This is the code behind 'cobbler sync'.
 
-Copyright 2006-2009, Red Hat, Inc
-Michael DeHaan <mdehaan@redhat.com>
+Copyright 2006-2009, Red Hat, Inc and Others
+Michael DeHaan <michael.dehaan AT gmail>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@ import sys
 import glob
 import traceback
 import errno
+import urlparse
 
 import utils
 from cexceptions import *
@@ -138,7 +139,12 @@ class KickGen:
             cobblerElement.appendChild( cobblerElementSystem )
             cobblerElement.appendChild( cobblerElementProfile )
 
-            document.childNodes[1].insertBefore( cobblerElement, document.childNodes[1].childNodes[1])
+            # FIXME: this is all broken and no longer works. 
+            #        this entire if block should probably not be
+            #        hard-coded anyway
+            #self.api.log(document.childNodes[2].childNodes)
+            #document.childNodes[1].insertBefore( cobblerElement, document.childNodes[2].childNodes[1])
+            #document.childNodes[1].insertBefore( cobblerElement, document.childNodes[1].childNodes[0])
 
         name = profile.name
         if system is not None:
@@ -175,6 +181,9 @@ class KickGen:
             # see if this is a source_repo or not
             repo_obj = self.api.find_repo(repo)
             if repo_obj is not None:
+                yumopts=''
+                for opt in repo_obj.yumopts:
+                    yumopts = yumopts + " %s=%s" % (opt,repo_obj.yumopts[opt])
                 if not repo_obj.yumopts.has_key('enabled') or repo_obj.yumopts['enabled'] == '1':
                    if repo_obj.mirror_locally:
                        baseurl = "http://%s/cobbler/repo_mirror/%s" % (blended["http_server"], repo_obj.name)
@@ -183,7 +192,7 @@ class KickGen:
                        included[baseurl] = 1
                    else:
                        if not included.has_key(repo_obj.mirror):
-                           buf = buf + "repo --name=%s --baseurl=%s\n" % (repo_obj.name, repo_obj.mirror)
+                           buf = buf + "repo --name=%s --baseurl=%s %s\n" % (repo_obj.name, repo_obj.mirror, yumopts)
                        included[repo_obj.mirror] = 1
             else:
                 # FIXME: what to do if we can't find the repo object that is listed?
@@ -263,6 +272,11 @@ class KickGen:
         meta["kernel_options"] = utils.hash_to_string(meta["kernel_options"])
         # meta["config_template_files"] = self.generate_template_files_stanza(g, False)
 
+        # add extra variables for other distro types
+        if "tree" in meta:
+            urlparts = urlparse.urlsplit(meta["tree"])
+            meta["install_source_directory"] = urlparts[2]
+
         try:
             raw_data = utils.read_file_contents(kickstart_path, self.api.logger,
                     self.settings.template_remote_kickstarts)
