@@ -2,8 +2,8 @@
 Authentication module that defers to Apache and trusts
 what Apache trusts.
 
-Copyright 2008, Red Hat, Inc
-Michael DeHaan <mdehaan@redhat.com>
+Copyright 2008-2009, Red Hat, Inc and Others
+Michael DeHaan <michael.dehaan AT gmail>
 
 This software may be freely redistributed under the terms of the GNU
 general public license.
@@ -16,6 +16,7 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 import distutils.sysconfig
 import sys
 import os
+from cobbler import utils
 from utils import _
 import traceback
 
@@ -37,13 +38,10 @@ def authenticate(api_handle,username,password):
     Validate a username/password combo, returning True/False
     Uses cobbler_auth_helper
     """
-
-    fd = open("/var/lib/cobbler/web.ss")
-    data = fd.read()
-    if password == data:
-       rc = 1
+    ss = utils.get_shared_secret()
+    if password == ss:
+       rc = True
     else:
-       rc = 0
-    fd.close()
-    return data
+       rc = False
+    return rc
 
