@@ -1,9 +1,8 @@
-
 """
 This is some of the code behind 'cobbler sync'.
 
-Copyright 2006-2008, Red Hat, Inc
-Michael DeHaan <mdehaan@redhat.com>
+Copyright 2006-2009, Red Hat, Inc and Others
+Michael DeHaan <michael.dehaan AT gmail>
 John Eckersberg <jeckersb@redhat.com>
 
 This program is free software; you can redistribute it and/or modify
@@ -26,12 +25,10 @@ import os
 import os.path
 import shutil
 import time
-import sub_process
 import sys
 import glob
 import traceback
 import errno
-import popen2
 from shlex import shlex
 import utils
 from cexceptions import *
@@ -50,11 +47,11 @@ class DnsmasqManager:
     Handles conversion of internal state to the tftpboot tree layout
     """
 
-    def __init__(self,config,verbose=False,dhcp=None):
+    def __init__(self,config,logger,dhcp=None):
         """
         Constructor
         """
-        self.verbose     = verbose
+        self.logger      = logger
         self.config      = config
         self.api         = config.api
         self.distros     = config.distros()
@@ -79,8 +76,8 @@ class DnsmasqManager:
         DHCP files are written when manage_dhcp is set in
         /var/lib/cobbler/settings.
         """
-        
-        settings_file = self.settings.dnsmasq_conf
+       
+        settings_file = "/etc/dnsmasq.conf"
         template_file = "/etc/cobbler/dnsmasq.template"
 
         try:
@@ -117,31 +114,35 @@ class DnsmasqManager:
 
                 mac  = interface["mac_address"]
                 ip   = interface["ip_address"]
-                host = interface["hostname"]
+                host = interface["dns_name"]
 
                 if mac is None or mac == "":
                     # can't write a DHCP entry for this system
                     continue 
  
                 counter = counter + 1
-                systxt = "" 
 
-                # dnsmasq.  don't have to write IP and other info here, but we do tag
-                # each MAC based on the arch of it's distro, if it needs something other
-                # than pxelinux.0 -- for these arches, and these arches only, a dnsmasq
-                # reload (full "cobbler sync") would be required after adding the system
-                # to cobbler, just to tag this relationship.
+                # In many reallife situations there is a need to control the IP address 
+                # and hostname for a specific client when only the MAC address is available.
+                # In addition to that in some scenarios there is a need to explicitly 
+                # label a host with the applicable architecture in order to correctly 
+                # handle situations where we need something other than pxelinux.0.
+                # So we always write a dhcp-host entry with as much info as possible
+                # to allow maximum control and flexibility within the dnsmasq config
+
+                systxt = "dhcp-host=net:" + distro.arch.lower() + "," + mac
+
+                if host is not None and host != "":
+                    systxt = systxt + "," + host
 
                 if ip is not None and ip != "":
-                    if distro.arch.lower() == "ia64":
-                        systxt = "dhcp-host=net:ia64," + ip + "\n"
-                    # support for other arches needs modifications here
-                    else:
-                        systxt = ""
+                    systxt = systxt + "," + ip
+
+                systxt = systxt + "\n" 
 
                 dhcp_tag = interface["dhcp_tag"]
                 if dhcp_tag == "":
-                   dhcp_tag = "default"
+                    dhcp_tag = "default"
 
                 if not system_definitions.has_key(dhcp_tag):
                     system_definitions[dhcp_tag] = ""
@@ -150,8 +151,6 @@ class DnsmasqManager:
         # we are now done with the looping through each interface of each system
 
         metadata = {
-           "omapi_enabled"  : self.settings.omapi_enabled,
-           "omapi_port"     : self.settings.omapi_port,
            "insert_cobbler_system_definitions" : system_definitions.get("default",""),
            "date"           : time.asctime(time.gmtime()),
            "cobbler_server" : self.settings.server,
@@ -194,7 +193,7 @@ class DnsmasqManager:
                 continue
             for (name, interface) in system.interfaces.iteritems():
                 mac  = interface["mac_address"]
-                host = interface["hostname"]
+                host = interface["dns_name"]
                 ip   = interface["ip_address"]
                 if mac is None or mac == "":
                     continue
@@ -206,6 +205,5 @@ class DnsmasqManager:
         # already taken care of by the regen_hosts()
         pass
 
-def get_manager(config):
-    return DnsmasqManager(config)
-
+def get_manager(config,logger):
+    return DnsmasqManager(config,logger)
