@@ -36,7 +36,6 @@ import item_distro
 import item_profile
 import item_repo
 import item_system
-import codes
 
 from utils import _
 
@@ -181,7 +180,7 @@ class ImportRedhatManager:
 
     # required function for import modules
     def get_valid_os_versions(self):
-        return codes.VALID_OS_VERSIONS["redhat"]
+        return utils.get_valid_os_versions_for_breed("redhat")
 
     def get_valid_repo_breeds(self):
         return ["rsync", "rhn", "yum",]
@@ -764,11 +763,6 @@ class ImportRedhatManager:
 
         if flavor == "fedora":
 
-            # this may actually fail because the libvirt/virtinst database
-            # is not always up to date.  We keep a simplified copy of this
-            # in codes.py.  If it fails we set it to something generic
-            # and don't worry about it.
-
             try:
                 os_version = "fedora%s" % int(major)
             except:
