@@ -16,15 +16,9 @@
 
 import os
 import os.path
-import shutil
-import time
-import sys
 import glob
 import traceback
 import errno
-from utils import popen2
-from shlex import shlex
-
 
 import utils
 from cexceptions import *
@@ -125,6 +119,10 @@ class ImportSuseManager:
         # FIXME : search below self.path for isolinux configurations or known directories from TRY_LIST
         os.path.walk(self.path, self.distro_adder, distros_added)
 
+        if len(distros_added) == 0:
+            self.logger.warning("No distros imported, bailing out")
+            return False
+
         # find out if we can auto-create any repository records from the install tree
 
         if self.network_root is None:
@@ -196,7 +194,7 @@ class ImportSuseManager:
             # and the input start directory in the crawl.  We find the path segments
             # between and tack them on the network source path to find the explicit
             # network path to the distro that Anaconda can digest.
-            tail = self.path_tail(self.path, base)
+            tail = utils.path_tail(self.path, base)
             tree = self.network_root[:-1] + tail
             self.set_install_tree(distro, tree)
 
@@ -324,9 +322,9 @@ class ImportSuseManager:
             archs = [ proposed_arch ]
 
         if len(archs)>1:
-            if self.breed in [ "suse" ]:
-                self.logger.warning("directory %s holds multiple arches : %s" % (dirname, archs))
-                return
+            #if self.breed in [ "suse" ]:
+            #    self.logger.warning("directory %s holds multiple arches : %s" % (dirname, archs))
+            #    return
             self.logger.warning("- Warning : Multiple archs found : %s" % (archs))
 
         distros_added = []
@@ -352,7 +350,7 @@ class ImportSuseManager:
             distro.set_initrd(initrd)
             distro.set_arch(pxe_arch)
             distro.set_breed(self.breed)
-            distro.set_kernel_options("install=http://@@http_server@@/cblr/links/%s" % (name))
+            distro.set_kernel_options("install=http://%s/cblr/links/%s" % (self.settings.server, name))
             # If a version was supplied on command line, we set it now
             if self.os_version:
                 distro.set_os_version(self.os_version)
@@ -427,7 +425,7 @@ class ImportSuseManager:
         """
 
         if self.network_root is not None:
-            name = self.name + "-".join(self.path_tail(os.path.dirname(self.path),dirname).split("/"))
+            name = self.name
         else:
             # remove the part that says /var/www/cobbler/ks_mirror/name
             name = "-".join(dirname.split("/")[5:])
@@ -552,7 +550,7 @@ class ImportSuseManager:
             # SELinux Apache can't symlink to NFS (without some doing)
             if not os.path.exists(dest_link):
                 try:
-                    os.symlink(base + "-" + distro.arch, dest_link)
+                    os.symlink(base, dest_link)
                 except:
                     # this shouldn't happen but I've seen it ... debug ...
                     self.logger.warning("symlink creation failed: %(base)s, %(dest)s") % { "base" : base, "dest" : dest_link }
