@@ -2,8 +2,8 @@
 Serializer code for cobbler
 Now adapted to support different storage backends
 
-Copyright 2006-2009, Red Hat, Inc
-Michael DeHaan <mdehaan@redhat.com>
+Copyright 2006-2009, Red Hat, Inc and Others
+Michael DeHaan <michael.dehaan AT gmail>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -64,11 +64,9 @@ def __release_lock(with_changes=False):
         # this file is used to know when the last config change
         # was made -- allowing the API to work more smoothly without
         # a lot of unneccessary reloads.  
-        old = os.umask(0x777)
-        fd = open("/var/lib/cobbler/.mtime","w")
-        fd.write("%f" % time.time())
-        fd.close()
-        os.umask(old)
+        fd = os.open("/var/lib/cobbler/.mtime", os.O_CREAT|os.O_RDWR, 0200)
+        os.write(fd, "%f" % time.time())
+        os.close(fd)
     if LOCK_ENABLED:
         LOCK_HANDLE = open("/var/lib/cobbler/lock","r")
         fcntl.flock(LOCK_HANDLE.fileno(), fcntl.LOCK_UN)
