@@ -1,6 +1,6 @@
 # Test cases for Cobbler
 #
-# Michael DeHaan <mdehaan@redhat.com>
+# Michael DeHaan <michael.dehaan AT gmail>
 
 import sys
 import unittest
@@ -402,7 +402,7 @@ class MultiNIC(BootTest):
         self.assertTrue(system.set_dns_name("fooserver","eth4"))
         self.assertTrue(system.set_dhcp_tag("red","eth4"))
         self.assertTrue(system.set_ip_address("192.168.1.26","eth4"))
-        self.assertTrue(system.set_subnet("255.255.255.0","eth4"))
+        self.assertTrue(system.set_netmask("255.255.255.0","eth4"))
         self.assertTrue(system.set_dhcp_tag("tag2","eth5"))
         self.assertTrue(self.api.add_system(system))
         self.assertTrue(self.api.find_system(dns_name="fooserver"))
@@ -410,7 +410,7 @@ class MultiNIC(BootTest):
         self.assertTrue(self.api.find_system(ip_address="127.0.0.5"))
         self.assertTrue(self.api.find_system(virt_bridge="zero"))
         self.assertTrue(self.api.find_system(gateway="192.168.1.25"))
-        self.assertTrue(self.api.find_system(subnet="255.255.255.0"))
+        self.assertTrue(self.api.find_system(netmask="255.255.255.0"))
         self.assertTrue(self.api.find_system(dhcp_tag="tag2"))
         self.assertTrue(self.api.find_system(dhcp_tag="zero"))
 
@@ -425,7 +425,7 @@ class MultiNIC(BootTest):
         for (name,intf) in system.interfaces.iteritems():
             if name == "eth4": # xmlrpc dicts must have string keys, so we must also
                 self.assertTrue(intf["virt_bridge"] == "zero")
-                self.assertTrue(intf["subnet"] == "255.255.255.0")
+                self.assertTrue(intf["netmask"] == "255.255.255.0")
                 self.assertTrue(intf["mac_address"] == "AA:AA:BB:BB:CC:CC")
                 self.assertTrue(intf["ip_address"] == "192.168.1.26")
                 self.assertTrue(intf["dns_name"] == "fooserver")
@@ -463,6 +463,12 @@ class Utilities(BootTest):
     def test_matching(self):
         self.assertTrue(utils.is_mac("00:C0:B7:7E:55:50"))
         self.assertTrue(utils.is_mac("00:c0:b7:7E:55:50"))
+        self.assertFalse(utils.is_mac("00:c0:b:7E:55:50"))
+        self.assertFalse(utils.is_mac("00:c0:b7:7E:55"))
+        self.assertFalse(utils.is_mac("00:c0:b7:7E:55:50:0F"))
+        self.assertFalse(utils.is_mac("00:c0:bZ:7E:55:50"))
+        self.assertFalse(utils.is_mac("x00:c0:b7:7E:55:50"))
+        self.assertFalse(utils.is_mac("00:c0:b7:7E:55:50x"))
         self.assertFalse(utils.is_mac("00.D0.B7.7E.55.50"))
         self.assertFalse(utils.is_mac("testsystem0"))
         self.assertTrue(utils.is_ip("127.0.0.1"))
@@ -535,6 +541,7 @@ class Utilities(BootTest):
         self.assertTrue(profile.set_distro("testdistro0"))
         self.assertTrue(profile.set_kickstart("http://127.0.0.1/foo"))
         self.assertTrue(profile.set_virt_bridge("xenbr1"))
+        self.assertTrue(profile.set_disk_driver("qcow"))
         # sizes must be integers
         self.assertTrue(profile.set_virt_file_size("54321"))
         self.failUnlessRaises(Exception, profile.set_virt_file_size, "huge")
