@@ -1,8 +1,8 @@
 """
 registration tool for cobbler.
 
-Copyright 2009 Red Hat, Inc.
-Michael DeHaan <mdehaan@redhat.com>
+Copyright 2009 Red Hat, Inc and Others.
+Michael DeHaan <michael.dehaan AT gmail>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ import utils
 import string
 import pprint
 
-# usage: cobbler-register [--server=server] [--hostname=hostname] --profile=foo
+# usage: cobbler-register [--server=server] [--fqdn=hostname] --profile=foo
 
 
 def main():
